Module remove_items_from_playlist

Module remove_items_from_playlist 

Functions

remove_items_at_positions
Remove items at specific positions from a playlist Takes a list of (uri, position) tuples Note: Positions must be provided in descending order to avoid index shifting issues
remove_items_from_playlist
Remove all instances of the given URIs from a playlist