Module api

Module api 

Authenticated Spotify Web API client.

All requests are made with Bearer token authentication to api.spotify.com/v1. Includes automatic retry with exponential backoff for rate limiting.

Structs

SpotifyApi
Spotify Web API client.