pub struct FormatterRegistry { /* private fields */ }Expand description
Registry holding all formatters in priority order
Implementations
Sourceimpl FormatterRegistry
impl FormatterRegistry
pub fn new() -> Self
Sourcepub fn format(&self, payload: &Value, message: &str)
pub fn format(&self, payload: &Value, message: &str)
Format the payload using the first matching formatter (legacy, uses payload inspection)
Sourcepub fn format_with_kind(
&self,
payload: &Value,
message: &str,
kind: Option<PayloadKind>,
)
pub fn format_with_kind( &self, payload: &Value, message: &str, kind: Option<PayloadKind>, )
Format the payload, optionally using a type hint for reliable matching.