macro_rules! log_command {
($cmd:expr) => { ... };
($cmd:expr, $($field:tt)*) => { ... };
}Expand description
Helper macro for structured command logging.
Use at the start of command handlers to log command execution.
macro_rules! log_command {
($cmd:expr) => { ... };
($cmd:expr, $($field:tt)*) => { ... };
}Helper macro for structured command logging.
Use at the start of command handlers to log command execution.