pub fn calculate_score(name: &str, query: &str, config: &FuzzyConfig) -> f64Expand description
Calculate fuzzy match score for a name against a query Returns 0.0 for no match, higher values for better matches
pub fn calculate_score(name: &str, query: &str, config: &FuzzyConfig) -> f64Calculate fuzzy match score for a name against a query Returns 0.0 for no match, higher values for better matches