PKCE (Proof Key for Code Exchange) implementation.
PKCE is an extension to OAuth 2.0 that protects authorization codes from interception. It works by creating a cryptographic challenge that proves the token request comes from the same client that initiated the authorization.
See: RFC 7636
Structs
- Pkce
Challenge - PKCE challenge and verifier pair.